==> owncloud_8.0.16.orig.tar.gz: owncloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "A file or folder has been <strong>shared</strong>" : "Sebuah berkas atau folder telah <strong>dibagikan</strong>",
    "A new file or folder has been <strong>created</strong>" : "Sebuah berkas atau folder baru telah <strong>dibuat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder telah <strong>diubah</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Sebuah berkas atau folder telah <strong>dihapus</strong>",
    "A file or folder has been <strong>restored</strong>" : "Sebuah berkas atau folder telah <strong>dipulihkan</strong>",
    "You created %1$s" : "Anda membuat %1$s",
    "%2$s created %1$s" : "%2$s membuat %1$s",
    "%1$s was created in a public folder" : "%1$s telah dibuat di folder publik",
    "You changed %1$s" : "Anda mengubah %1$s",
    "%2$s changed %1$s" : "%2$s mengubah %1$s",
    "You deleted %1$s" : "Anda menghapus %1$s",
    "%2$s deleted %1$s" : "%2$s menghapus %1$s",
    "You restored %1$s" : "Anda memulihkan %1$s",
    "%2$s restored %1$s" : "%2$s memulihkan %1$s",
    "You shared %1$s with %2$s" : "Anda membagikan %1$s dengan %2$s",
    "You shared %1$s with group %2$s" : "Anda membagikan %1$s dengan grup %2$s",
    "%2$s shared %1$s with you" : "%2$s membagikan %1$s dengan Anda",
    "You shared %1$s via link" : "Anda membagikan %1$s via tautan",
    "Activity notification" : "Pemberitahuan aktivitas",
    "All Activities" : "Semua Aktivitas",
    "Activities by you" : "Aktivitas oleh Anda",
    "Activities by others" : "Aktivitas oleh orang lain",
    "Shares" : "Dibagikan",
    "Files" : "Berkas",
    "in %s" : "dalam %s",
    "%s and %s" : "%s dan %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s dan <strong class=\"tooltip\" title=\"%s\">%n lainnya</strong>"],
    "%s and %n more::%s and %n more" : ["%s dan %n lainnya"],
    "Hello %s," : "Helo %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Anda menerima email ini karena dalam satu jam terakhir hal-hal berikut terjadi di %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Anda menerima email ini karena dalam satu hari terakhir hal-hal berikut terjadi di %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Anda menerima email ini karena dalam satu minggu terakhir hal-hal berikut terjadi di %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "Anda akan melihat daftar peristiwa disini ketika mulai menggunakan %s Anda.",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "Notifications" : "Pemberitahuan",
    "Mail" : "Email",
    "Stream" : "Alir",
    "List your own actions in the stream" : "Daftar aksi oleh Anda didalam alir",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Activity feed" : "Feed aktivitas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s"
},
"nplurals=1; plural=0;");

==> owncloud_8.1.12.orig.tar.gz: owncloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL feed Anda tidak sah",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan agenda seperti penambahan, perubahan & berbagi",
    "There are no events for this filter" : "Tidak ada agenda untuk penyaring ini",
    "Activity notification" : "Pemberitahuan aktivitas",
    "All Activities" : "Semua Aktivitas",
    "Activities by you" : "Aktivitas oleh Anda",
    "Activities by others" : "Aktivitas oleh orang lain",
    "\"remote user\"" : "\"remote user\"",
    "in %s" : "dalam %s",
    "%s and %s" : "%s dan %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s dan <strong class=\"tooltip\" title=\"%s\">%n lainnya</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s dan %n lainnya"],
    "Hello %s," : "Helo %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Anda menerima email ini karena dalam satu jam terakhir hal-hal berikut terjadi di %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Anda menerima email ini karena dalam satu hari terakhir hal-hal berikut terjadi di %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Anda menerima email ini karena dalam satu minggu terakhir hal-hal berikut terjadi di %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* dan %n lagi "],
    "Notifications" : "Pemberitahuan",
    "Mail" : "Email",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Daftar aksi oleh Anda didalam alir",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Activity feed" : "Feed aktivitas",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "No activity yet" : "Masih tidak ada aktivitas",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Files" : "Berkas"
},
"nplurals=1; plural=0;");
